<?php

/*
You can use existing WordPress template tags for terms and taxonomies.

These templates tags are described in Wordpress Codex at http://codex.wordpress.org/Template_Tags

$description = term_description( $term = 0, EGS_TAXONOMY )
 * Retrieve serie description.
 * @since 2.8
 * @File: wp-includes/category-template.php
 * @param int $term Optional. Term ID. Will use global term ID by default.
 * @return string Term description if available.

$series_list = get_the_term_list( $id , EGS_TAXONOMY, $before, $sep, $after)
 * Find all series in which a post is attached
 * @since 2.5.0
 * @file wp-includes/category-template.php
 * @param int $id Post ID. To get series for the current post: $post->ID
 * @param string $before Optional. Before list.
 * @param string $sep Optional. Separate items using this.
 * @param string $after Optional. After list.
 * @return string

the_terms( $id, EGS_TAXONOMY, $before, $sep, $after)
 * Display the terms in a list.
 * @since 2.5.0
 * @file wp-includes/category-template.php
 * @param int $id Term ID.
 * @param string $before Optional. Before list.
 * @param string $sep Optional. Separate items using this.
 * @param string $after Optional. After list.
 * @return null|bool False on WordPress error. Returns null when displaying.

$series_list = get_terms(EGS_TAXONOMY, $args)
 * Retrieve the list of all series
 * @since 2.3.0
 * @file wp-includes/taxonomy.php
 * @param string|array $args The values of what to search for when returning terms
 * @return array|WP_Error List of Term Objects and their children. Will return WP_Error, if any of $taxonomies do not exist.
 * Args can contain: orderby (, order (asc or desc), hide_empty (true or false), exlude, include, number, offset, fields (all, ids, names)

$serie_fields = get_term($term, EGS_TAXONOMY, $output, $filter)
 * Get information of a specific serie
 * @since 2.3.0
 * @file wp-includes/taxonomy.php
 * @param int|object $term If integer, will get from database. If object will apply filters and return $term.
 * @param string $output Constant OBJECT, ARRAY_A, or ARRAY_N
 * @param string $filter Optional, default is raw or no WordPress defined filter will applied.
 * @return mixed|null|WP_Error Term Row from database. Will return null if $term is empty. If taxonomy does not
 * exist then WP_Error will be returned.

$link = get_term_link( $term, EGS_TAXONOMY)
 * Generates a permalink for a taxonomy term archive.
 * @since 2.5.0
 * @file wp-includes/taxonomy.php
 * @param object|int|string $term (serie's id or serie's slug)
 * @param string $taxonomy (optional if $term is object)
 * @return string HTML link to taxonomy term archive

*/

if (! function_exists('is_tax')) {

	/**
	 * Is the query for a taxonomy archive page?
	 *
	 * @param mixed $taxonomy Optional. Taxonomy slug or slugs. For EG-Series specify EGS_TAXONOMY
	 * @param mixed $term. Optional. Term ID, name, slug or array of Term IDs, names, and slugs.
	 * @return bool
	 */
	function is_tax( $taxonomy = '', $term = '' ) {
		global $wp_taxonomies;

		if ( empty( $taxonomy ) )
			return true;

		$queried_object = $this->get_queried_object();
		$tax_array = array_intersect( array_keys( $wp_taxonomies ), (array) $taxonomy );
		$term_array = (array) $term;

		if ( empty( $term ) ) // Only a Taxonomy provided
			return isset( $queried_object->taxonomy ) && count( $tax_array ) && in_array( $queried_object->taxonomy, $tax_array );

		return isset( $queried_object->term_id ) &&
			count( array_intersect(
				array( $queried_object->term_id, $queried_object->name, $queried_object->slug ),
				$term_array
			) );
	}
} // End of if is_tax not exists

/**
 * eg_series_list_series
 *
 * Implement a shortcode to get the list of the series
 *
 * @param 	array		$attr		list of parameters sent to the shortcde
 * @return 	string			html code
 */
function eg_series_list_series($attr) {
	global $eg_series;
	
	return ($eg_series->series_shortcode($attr));

} // End of eg_series_list_series

/**
 * eg_series_list_posts
 *
 * Display the list of posts for a specified serie
 *
 * @param 	array		$attr		list of parameters sent to the shortcde
 * @return 	string					html code
 */
function eg_series_list_posts($attr) {
	global $eg_series;

	return ($eg_series->posts_shortcode($attr));

} // End of eg_series_list_posts

?>