<?php

if (eg_detect_page('egs_options')) {
	require(dirname(EGS_CORE_FILE).'/lib/eg-forms.inc.php');
}

if (! class_exists('EG_Series_Admin')) {

	/**
	 * Class EG_Series_Admin
	 *
	 * Implement a shortcode to display the posts series
	 *
	 */
	Class EG_Series_Admin extends EG_Plugin_122 {

		function init() {

			// Call the parent init function
			parent::init();

			EG_Series_Core::create_taxonomy($this->textdomain, $this->options['custom_post_types']);

			// Add columns to the post list (menu Manage)
			if ($this->options['display_columns']) {
				$post_type = isset($_REQUEST['post_type']) ? $_REQUEST['post_type'] : 'post';
				switch($post_type){
					case 'post':
					case 'page':
						add_filter('manage_posts_columns', array(&$this, 'manage_col_def') );
						add_action('manage_posts_custom_column', array(&$this, 'manage_col'), 10, 2 );
					break;

					default:
						if (in_array($post_type, $this->options['custom_post_types'])) {
							add_filter("manage_{$post_type}_posts_columns", array(&$this, 'manage_col_def') );
							add_action("manage_{$post->post_type}_posts_custom_column", array(&$this, 'manage_col'), 10, 2 );
						}
					break;
				} // End of switch $post_type
			} // End of display_columns

			if ($this->options['display_dashboard'])
				add_action('right_now_content_table_end', array(&$this, 'display_num_series_dashboard')) ;

			add_action('wp_ajax_eg_series_update', array(&$this, 'bulk_posts_series_update') );

		} // End of init

		function admin_menu() {

			$this->add_page( array(
					'id' 				=> 'egs_options',
					'display_callback'	=> 'options_page')
			);

			$this->add_page( array(
					'id' 				=> 'egs_post_edit',
					'type'				=> 'posts',
					'page_title' 		=> 'EG-Series Bulk Edit',
					'menu_title'		=> 'EG-Series Bulk Edit',
					'access_level'		=> $this->options['access_level'],
					'display_callback'	=> 'bulk_edition',
					'load_scripts'		=> 'bulk_edition_load_scripts')
			);

			parent::admin_menu();

			if (class_exists('EG_Form_210')) {
				require($this->path.'inc/eg-series-settings.inc.php');
			} // End of class_exists

		} // End of admin_menu

		function display_sidebar() {
			global $locale;

			$string = sprintf('<ul>'.
							  '<li><a href="http://wordpress.org/extend/plugins/eg-series/">%s</a></li>'.
							  '<li><a href="http://wordpress.org/extend/plugins/eg-series/faq">%s</a></li>'.
							  '<li><a href="http://wordpress.org/tags/eg-series">%s</a></li>'.
							  '<li><a href="http://wordpress.org/extend/plugins/eg-series/changelog/">%s</a></li>'.
							  '</ul>',
							__('Plugin\'s homepage', 		$this->textdomain),
							__('Frequently Asked Questions',$this->textdomain),
							__('Support forum', 			$this->textdomain),
							__('Last changes', 				$this->textdomain));
			$this->display_box('links', 'Links', $string);

			$string = '<p>'.__('This plugin required and requires many hours of work. If you use the plugin, and like it, feel free to show your appreciation to the author.', $this->textdomain).'</p>';
			$string .= '<form action="https://www.paypal.com/cgi-bin/webscr" method="post">'.
						'<input type="hidden" name="cmd" value="_donations">'.
						'<input type="hidden" name="business" value="CPCKAJFRB5NNA">'.
						'<input type="hidden" name="lc" value="'.($locale=='fr_FR'?'FR':'US').'">'.
						'<input type="hidden" name="item_number" value="eg-series">'.
						'<input type="hidden" name="currency_code" value="EUR">'.
						'<input type="hidden" name="bn" value="PP-DonationsBF:btn_donate_LG.gif:NonHosted">'.
						'<input type="image" src="https://www.paypalobjects.com/'.($locale=='fr_FR'?'fr_FR':'en_US').'/i/btn/btn_donate_LG.gif" border="0" name="submit" alt="'.__('PayPal - The safer, easier way to pay online!', $this->textdomain).'">'.
						'<img alt="" border="0" src="https://www.paypalobjects.com/'.($locale=='fr_FR'?'fr_FR':'en_US').'/i/scr/pixel.gif" width="1" height="1">'.
						'</form>';
			$this->display_box('paypal', 'Donate', $string);
		} // End of display_sidebar

		function options_page() {
			if (isset($this->options_form))
				$this->options_form->display_page($this->options);
		} // End of options_page

		/**
		 * bulk_edition_display_series
		 *
		 * Display series
		 *
		 * @param 	none
		 * @return 	none
		 */
		function bulk_edition_display_series($series_slug, $box) {

			$serie_id   = (int)substr($box['id'], strlen('seriebox-'));

			$posts = get_posts(array(
					EGS_TAXONOMY  => $series_slug[$serie_id],
					'orderby'			=> 'menu_order',
					'order'				=> 'ASC',
					'post_type'			=> array_merge(array('post', 'page'), $this->options['custom_post_types']),
					'posts_per_page'	=> -1)
				);

			$output = '<ul id="serie-'.$serie_id.'" class="eg-series egseries-sortable">';
			if (is_array($posts)) {
				foreach ($posts as $post) {
					$debug_info = (EGS_DEBUG_MODE?$post->ID.' - '.$post->menu_order.' - ':'');
					$output .= '<li id="post-'.$post->ID.'">'.$debug_info.htmlspecialchars($post->post_title).'</li>';
				}
			}
			$output .= '</ul>';
			echo $output;

		} // End of bulk_posts_display_posts

		/**
		 * Display a monthly dropdown for filtering items
		 *
		 * @since 3.1.0
		 * @access protected
		 */
		function months_dropdown( $post_type, $selected ) {
			global $wpdb, $wp_locale;
/*
			$months = $wpdb->get_results( $wpdb->prepare( "
				SELECT DISTINCT YEAR( post_date ) AS year, MONTH( post_date ) AS month
				FROM $wpdb->posts
				WHERE post_type = %s
				ORDER BY post_date DESC
			", $post_type ) );
*/
			$months = $wpdb->get_results( "SELECT DISTINCT YEAR(post_date) AS year, MONTH(post_date) AS month FROM {$wpdb->posts} ORDER BY post_date DESC");
			$string = '';
			foreach ( $months as $arc_row ) {
				if ( 0 == $arc_row->year )
					continue;

				$value = $arc_row->year.zeroise( $arc_row->month, 2 );
				$string .= '<option value="'.$value.'" '.($value==$selected?'selected':'').'>'.
						$wp_locale->get_month($arc_row->month).' '.$arc_row->year.
						'</option>';
			}
			if ($string != '')
				$string = '<select name="m">'.
							'<option value="0" '.(0==$selected?'selected':'').'>'.__( "Show all dates", $this->textdomain ).'</option>'.
							$string.
						'</select>';

			return ($string);

		} // End of months_dropdown

		/**
		 * bulk_edition_display_posts
		 *
		 * Display posts list and filters
		 *
		 * @param 	none
		 * @return 	none
		 */
		function bulk_edition_display_posts($data) {

			// Get date parameter
			$status_title = array(
				'any'     => __('All posts', $this->textdomain),
				'future'  => __('Future',   $this->textdomain),
				'publish' => __('Published', $this->textdomain),
				'draft'   => __('Draft',     $this->textdomain),
				'pending' => __('Pending',   $this->textdomain)
			);

			$date = isset($_GET['m'])?$_GET['m']:'';
			$params = array(
				'cat' 				=> isset($_GET['cat'])?$_GET['cat']:'',
				'year' 				=> substr($date, 0, 4),
				'monthnum' 			=> substr($date, 5),
				'paged' 			=> isset($_GET['paged'])?$_GET['paged']:1,
				'post_status' 		=> isset($_GET['post_status'])?$_GET['post_status']:'any',
				'posts_per_page'	=> 25,
				'orderby'			=> 'date',
				'order'				=> 'desc' /*,
				'post_type'			=> isset($_GET['post_type'])?$_GET['post_type']:'all' */
			);

			$slugs = array();
			$params['post__not_in'] = array();
			$series_list = get_terms(EGS_TAXONOMY, array('hide_empty' => false, 'hierarchical' => false));
			foreach ($series_list as $serie) {
				$slugs[] = $serie->slug;
			}

			// Post type management
/*			if ($params['post_type'] == 'all') {
				$params['post_type'] = array_merge(array('post', 'page'), $this->options['custom_post_types']);
			}
*/
			if (sizeof($slugs)>0) {
				$posts = get_posts(array(
							EGS_TAXONOMY  => implode(',',$slugs),
							'posts_per_page' => -1,
							'post_type'		=> array_merge(array('post', 'page'), $this->options['custom_post_types']))
						);

				if ($posts) {
					foreach ($posts as $post) {
						$params['post__not_in'][] = $post->ID;
					}
				}
			} // End of slug not empty

			$num_posts   = wp_count_posts('post', 'readable');
			$total_posts = array_sum( (array) $num_posts );
			$url_page    = admin_url('edit.php?page=egs_post_edit');
			$num_posts   = array_merge( array('any' => $total_posts), (array) $num_posts);
			foreach ($num_posts as $status => $number) {
				if (isset($status_title[$status])) {
					$class = ($params['post_status'] == $status ? ' class="current"' : '');
					$filter_post_status[] = '<li>'.
						'<a href="'.$url_page.($status=='any'?'':'&post_status='.$status).'" '.$class.'>'.
						$status_title[$status].' <span class="count">'.($number<0?'':'('.$number.')').'</span>'.
						'</a></li>';
				}
			} // End of foreach
/*
			$filter_post_type = '<select name="post_type">'.
						'<option value="all" '.(isset($_GET['post_type'])&&$_GET['post_type']=='all'?'selected':'').'>'.__('All', $this->textdomain).'</option>';
			foreach (array_merge(array('post', 'page'), $this->options['custom_post_types']) as $post_type_id) {
				$post_type = get_post_type_object($post_type_id);
				$filter_post_type .= '<option value="'.$post_type_id.'" '.(isset($_GET['post_type'])&&$_GET['post_type']==$post_type_id?'selected':'').'>'.$post_type->label.'</option>';
			}
			$filter_post_type .= '</select>';
*/

			$filter_archives   = $this->months_dropdown('', $date);
			$filter_categories = wp_dropdown_categories( array(
						'show_option_all'    => __('View all categories', $this->textdomain),
						'orderby'            => 'name',
						'show_count'         => 1,
						'hide_empty'         => 1,
						'echo'               => 0,
						'selected'           => $params['cat'])
				);


			query_posts( $params );

			global  $wp_query;
			$page_links = paginate_links(array(
						'base'		=> add_query_arg( 'paged', '%#%' ), /* '%_%', */
						/* 'format'    => '?paged=%#%', */
						'total'     => $wp_query->max_num_pages,
						'current'   => max( 1, $params['paged'])
					)
				);
?>
		<p class="description"><?php _e('Drag posts from here to a serie on the right to include them in a serie. Drag posts back here remove them from series.', $this->textdomain); ?></p>
		<div id="mass_edit_filter">
			<form id="posts-filter" method="get" action="">
				<input type="hidden" name="page" value="egs_post_edit" />
				<ul class="subsubsub">
					<?php echo implode(' | ', $filter_post_status); ?>
				</ul>
				<div class="tablenav top">
					<div class="alignleft actions">
						<?php echo $filter_archives; ?>
						<?php echo $filter_categories; ?>
						<?php /* echo $filter_post_type; */?>
						<input name="" id="post-query-submit" class="button-secondary" value="Filtrer" type="submit">
					</div>
					<div class="tablenav-pages">
						<?php echo $page_links ; ?>
					</div>
				</div>
				<br class="clear" />
			</form>
		</div>
			<ul id="posts-list" class="egseries-sortable">
<?php
				while (have_posts()) {
					the_post();
					echo '<li id="post-'.get_the_ID().'" >'.get_the_title().(EGS_DEBUG_MODE?' - '.get_post_type( get_the_ID() ):'').'</li>';
				}
?>
			</ul>
<?php
		} // End of bulk_edition_display_posts

		/**
		 * bulk_edition
		 *
		 * Display the bulk posts edition
		 *
		 * @param 	none
		 * @return 	none
		 */
		function bulk_edition() {

			$hook = $this->get_page_hook('egs_post_edit', __FUNCTION__);

			// Add main metabox (to display list of posts)
			add_meta_box('eg-series-posts-list', __('Available posts', $this->textdomain), array(&$this, 'bulk_edition_display_posts'), $hook, 'normal', 'core');

			// Add metaboxes for series
			$series_list = get_terms(EGS_TAXONOMY, array('hide_empty' => false, 'hierarchical' => false));
			$series_slug = array();
			// Get the list of series and store it in an array
			if ($series_list !==FALSE && sizeof($series_list) > 0) {
				foreach ($series_list as $serie) {
					add_meta_box('seriebox-'.$serie->term_id, $serie->name, array(&$this, 'bulk_edition_display_series'), $hook, 'side', 'core');
					$series_slug[$serie->term_id] = $serie->slug;
				}
			}
?>
			<div class="wrap">
			<?php screen_icon(); ?>
				<h2><?php _e('EG-Series Bulk Edit', $this->textdomain); ?></h2>
				<div id="ajax-wait" class="updated"><p><img height="16" width="16" src="<?php echo admin_url('images/loading.gif'); ?>"/> <?php _e('Processing, please wait ...', $this->textdomain); ?></p></div>
				<div id="ajax-response"> </div>
				<div id="poststuff" class="metabox-holder has-right-sidebar">
					<div id="side-info-column" class="inner-sidebar">
						<?php if (sizeof($series_slug)>0)  do_meta_boxes($hook, 'side', $series_slug); ?>
					</div>
					<div id="post-body" class="has-sidebar">
						<div id="post-body-content" class="has-sidebar-content">
							<?php do_meta_boxes($hook, 'normal', FALSE); ?>
						</div>
					</div>
					<br class="clear"/>
				</div>
			</div>
			<script type="text/javascript">
				//<![CDATA[
				jQuery(document).ready( function($) {
					postboxes.add_postbox_toggles('<?php echo $hook; ?>');
				});
				//]]>
			</script>
<?php
		} // End of bulk_edition

		/**
		 * bulk_edition_load_scripts
		 *
		 * Load JS scripts when the bulk edit posts is displayed
		 *
		 * @param 	none
		 * @return 	none
		 */
		function bulk_edition_load_scripts() {
			wp_enqueue_script('postbox');
			wp_enqueue_script('eg-series', $this->url.'inc/js/eg-series.js', array('jquery-ui-sortable'), '1.0.0', TRUE);
			wp_localize_script('eg-series', 'egSeriesSetup', array(
				'ajax_url'		 => admin_url('admin-ajax.php'),
				'UpdateSeries' 	 => 'eg_series_update',
				'nonce' 		 => wp_create_nonce( 'egseries-ajax' )
				)
			);
		} // End of bulk_edition_load_scripts

		/**
		 * bulk_posts_series_update
		 *
		 * Ajax function. Update series according actions in the admin interface
		 *
		 * @param 	none
		 * @return 	string		error code | message
		 */
		function bulk_posts_series_update() {

			if (EGS_DEBUG_MODE) $this->display_debug_info('POST: '.var_export($_REQUEST, TRUE));

			// Check nonce
			$error_code = 0;
			$msg = __('Serie successfully updated', $this->textdomain);
			if (! check_ajax_referer('egseries-ajax', 'eg_series_nonce', FALSE)) {
				$error_code = 3;
				$msg = __('Error, security check failed', $this->textdomain);
				if (EGS_DEBUG_MODE) $this->display_debug_info('check_ajax_referer FAILED');
			}
			else if ( ! current_user_can($this->options['access_level']) ) {
				$error_code = 4;
				$msg = __('Error, access denied', $this->textdomain);
				if (EGS_DEBUG_MODE) $this->display_debug_info('Error, access denied');
			}
			else {
				if (EGS_DEBUG_MODE) $this->display_debug_info('check_ajax_referer SUCCESSFUL');

				// get parameters
				$serie_id   = (int)substr($_POST['serie'], strlen('serie-'));
				$post_order = (isset($_POST['post'])?$_POST['post']:array());

				/*if (! is_array($post_order) || sizeof($post_order)== 0) {
					$error_code = 1;
					$msg = __('Error, cannot identify the post', $this->textdomain);
					if (EGS_DEBUG_MODE) $this->display_debug_info('Error code: 1');
				}
				else {
				*/
					// Get the serie
					$serie = get_term($serie_id, EGS_TAXONOMY);

					if (! $serie)  {
						$error_code = 2;
						$msg = __('Error, Serie not identified', $this->textdomain);
						if (EGS_DEBUG_MODE) $this->display_debug_info('Error code: 2');
					}
					else {
						if (EGS_DEBUG_MODE) $this->display_debug_info('Post_order: '.var_export($post_order, TRUE));
						$new_posts = array();
						foreach ($post_order as $key => $value) {
							$post_id = str_replace('post-', '', $value);
							$new_posts[$post_id] = $key;
						}
						//unset($post_order);
						if (EGS_DEBUG_MODE) $this->display_debug_info('New posts: '.var_export($new_posts, TRUE));
						if (EGS_DEBUG_MODE) $this->display_debug_info('get_posts parameters: '.var_export(array(EGS_TAXONOMY  => $serie->slug), TRUE));

						$posts = get_posts(array(
									EGS_TAXONOMY  => $serie->slug,
									'posts_per_page'	=> -1,
									'post_type'			=> array_merge(array('post', 'page'), $this->options['custom_post_types']))
								);
						$current_posts = array();
						foreach ($posts as $post) {
							$current_posts[$post->ID] = $post->menu_order;
						}
						if (EGS_DEBUG_MODE) $this->display_debug_info('Current posts: '.var_export($current_posts, TRUE));

						$posts_to_keep   = array_intersect_key($current_posts, 	$new_posts);
						$posts_to_delete = array_diff_key($current_posts, $posts_to_keep);
						$posts_to_add    = array_diff_key($new_posts, $posts_to_keep);

						if (EGS_DEBUG_MODE) $this->display_debug_info('Post to keep: '.var_export($posts_to_keep, TRUE));
						if (EGS_DEBUG_MODE) $this->display_debug_info('Posts_to_delete: '.var_export($posts_to_delete, TRUE));
						if (EGS_DEBUG_MODE) $this->display_debug_info('Post_to_add: '.var_export($posts_to_add, TRUE));

						foreach ($posts_to_delete as $post_id => $order) {
							if (EGS_DEBUG_MODE) $this->display_debug_info('Removing: '.$post_id);
							wp_delete_object_term_relationships($post_id, EGS_TAXONOMY);
						}
						foreach ($posts_to_add as $post_id => $order) {
							$result = wp_set_object_terms($post_id, $serie_id, EGS_TAXONOMY);
							if (EGS_DEBUG_MODE) $this->display_debug_info('Adding: '.$post_id.' in '.$serie_id.'_'.var_export($result, TRUE));
						}
					//	clean_object_term_cache($serie_id, EGS_TAXONOMY) ;

						// Re-order the list
						if (sizeof($new_posts)>0) {
							foreach ($new_posts as $post_id => $order) {
								$this->update_post_order($post_id, $order+1);
							} // End of re-order loop
						} // End of is_array($post_order)
					//} // End of no error
				} // End of user capabilities ok.
			} // End of "check ajax ok
			if (EGS_DEBUG_MODE) $this->display_debug_info('Returned code: '.$error_code);
			// Just concatenate error_code and string.
			// Still cannot use json_encode, because this function is only available since PHP 5.3
			die ($error_code.'|'.$msg);
		} // End of bulk_posts_series_update

		/**
		 * manage_col_def
		 *
		 * Display the header of the series column in the posts list
		 *
		 * @param 	array	$cols	List of columns
		 * @return 	array			Modified list of columns
		 */
		function manage_col_def($cols) {
			$cols['eg-serie'] = __('Series', $this->textdomain);
			return $cols;
		} // End of manage_col_def

		/**
		 * manage_col
		 *
		 * Display the serie value in the post list
		 *
		 * @param 	string	$column_name	Name of the column in the post list
		 * @param 	string	$id				(not used)
		 * @return 	none
		 */
		function manage_col($column_name, $id) {
			if ($column_name == 'eg-serie') {
				$series_list = get_the_terms( $id, EGS_TAXONOMY );
				if ($series_list) {
					$series_name = array();
					foreach ($series_list as $serie) {
						$series_name[] = $serie->name;
					}
					echo htmlspecialchars(implode(',', $series_name));
				} // End of this post has a serie
			} // End of column_name = Serie
		} // End of manage_col

		/**
		 * display_num_series_dashboard
		 *
		 * display the number of series in the dashboard
		 *
		 * @param 	none
		 * @return 	none
		 */
		function display_num_series_dashboard() {
			echo '<tr>'.
				'<td class="first b"><a href="'.admin_url('edit-tags.php?taxonomy=series').'">'.number_format_i18n( wp_count_terms(EGS_TAXONOMY) ).'</a></td>'.
				'<td class="t"><a href="'.admin_url('edit-tags.php?taxonomy=series').'">'.EGS_TAXONOMY_LABEL.'</a></td>'.
				'</tr>';
		} // End of display_num_series_dashboard

		/**
		 * install_upgrade
		 *
		 * Perform upgrade and required conversion
		 *
		 * @param 	none
		 * @return 	none
		 */
		function install_upgrade() {

			$previous_options = parent::install_upgrade();
			$previous_version = ($previous_options === FALSE ? FALSE : $previous_options['version']);
			if ($previous_version !== FALSE) { // Is it a new installation ?
			
				if (version_compare($previous_version, '2.0.0', '<')) {

					$previous_130 = version_compare($previous_version, '1.3.0', '<');
					$meta_key = (isset($previous_options['custom_field_name'])?$previous_options['custom_field_name']:'serie');
					global $wpdb;
					$sql = 'SELECT meta_id,meta_value,post_id,post_title,menu_order,post_date FROM '.$wpdb->postmeta.
							' INNER JOIN '.$wpdb->posts.' ON '.$wpdb->posts.'.ID = '.$wpdb->postmeta.'.post_id'.
							' WHERE meta_key="'.$meta_key.'" ORDER BY meta_value, post_date';
					$posts_list = $wpdb->get_results($sql);
					if (isset($posts_list) && is_array($posts_list) && sizeof($posts_list)>0) {
						//if (file_exists($this->path.'/update.log')) unlink($this->path.'/update.log');
						$serie = '';
						foreach ($posts_list as $post) {
							if ($serie != $post->meta_value) {
								$term = get_term_by('name', $post->meta_value, EGS_TAXONOMY);
								if ($term !== FALSE) {
									$term_id = intval($term->term_id);
								}
								else { // Term doesn't exist
									$term = wp_insert_term( $post->meta_value, EGS_TAXONOMY);
									$term_id = intval($term['term_id']);
								}
								$serie = $post->meta_value;
								$order_in_serie = 1;						
							}
							wp_set_object_terms($post->post_id, $term_id, EGS_TAXONOMY, FALSE);
							if ($previous_130) {
								$this->update_post_order($post->post_id, $order_in_serie);
							}
							$order_in_serie++;
						} // End of foreach posts

						$sql = 'DELETE FROM '.$wpdb->postmeta.' WHERE meta_key="'.$meta_key.'"';
						echo $sql.'<br />';
						$status = $wpdb->query($sql);
						echo var_export($status, TRUE).'<br/>';

					} // End of posts_list exist
				} // End of upgrade from 1.x to 2.x
			} // End of upgrade
		} // End of install_upgrade

		/**
		 * update_post_order
		 *
		 *
		 *
		 * @param 	$id			int		id of the post to modify
		 * @param 	$meta_key	string	meta key to use for series
		 * @param 	$order		int		order of the post in the serie
		 * @return 	none
		 */
		function update_post_order($id, $order) {
			global $wpdb;

			$sql = $wpdb->prepare('UPDATE '.$wpdb->posts.' SET menu_order=%u WHERE ID=%u', $order, $id );
			$wpdb->query($sql);
		} // End of update_post_order

	} // End of Class EG_Series_Admin

} // End of if class_exists

/* ---------------------------------------------------------------------------------------------------------
     --- Plugin instance creation
     ------------------------------------------------------------------------------------------------------- */
$eg_series_admin = new EG_Series_Admin(EGS_PLUGIN_NAME, EGS_VERSION, EGS_CORE_FILE,
										EGS_TEXTDOMAIN, EGS_OPTIONS_ENTRY, $EG_SERIES_DEFAULT_OPTIONS);
$eg_series_admin->set_stylesheets('css/eg-series-admin.css');
$eg_series_admin->add_tinymce_button( 'EGSeries', 'inc/tinymce', 'eg_series_tinymce.js');
$eg_series_admin->set_update_notice('Please check options');
$eg_series_admin->set_wp_versions('3.0', '3.3-beta2', TRUE);
if (EGS_DEBUG_MODE) $eg_series_admin->set_debug_mode(TRUE, 'debug.log');
$eg_series_admin->load();

?>