<?php

/* -------------------------------------------------------------------------
   --- Common data and fonctions, used by fron-end, back-end and widgets ---
   ------------------------------------------------------------------------- */

// Default options for shortcode [series] (list of all series)
define('EGS_DEFAULT_SERIES_ORDER_BY',	'name' );
define('EGS_DEFAULT_SERIES_ORDER',		'ASC'  );
define('EGS_DEFAULT_POSTS_ORDER_BY',	'date' );
define('EGS_DEFAULT_POSTS_ORDER',		'DESC' );
define('EGS_DEFAULT_AUTOSUBMIT',		1);

$EG_SERIES_SHORTCODE_SERIES_DEFAULTS = array(
	'title'	       => '',
	'titletag'     => 'h2',
	'listtype'     => 'ul',
	'number'       => 0,
	'more'         => 0,
	'listposts'    => 0,
	'show_date'    => 1,
	'post_orderby' => EGS_DEFAULT_POSTS_ORDER_BY,
	'post_order'   => EGS_DEFAULT_POSTS_ORDER,
	'numposts'	   => 0,
	'hide_empty'   => 1
);

// Default options for shortcode [seriesposts] (list of all posts of a specified serie)
$EG_SERIES_SHORTCODE_POSTS_DEFAULTS = array(
	'id'	    => 0,
	'name'	    => '',
	'title'	    => '',
	'titletag'  => 'h2',
	'listtype'  => 'ol',
	'orderby'   => EGS_DEFAULT_POSTS_ORDER_BY,
	'order'	    => EGS_DEFAULT_POSTS_ORDER,
	'show_date' => 1,
	'expand'    => 0
);

/**
 * Default options for the plugin
 *
 */
$EG_SERIES_DEFAULT_OPTIONS = array(
	'display_columns'       	  => 1,
	'display_dashboard'			  => 1,
	'access_level'  			  => 'manage_categories', /* manage_options for Admin, manage_categories for Editor, publish_posts for Author, edit_posts for Contributor */
	'shortcode_list_series' 	  => 'series',
	'shortcode_list_posts'  	  => 'seriesposts',
	'shortcode_auto' 			  => 0,
	'shortcode_auto_exclusive'	  => 1,
	'shortcode_auto_where'		  => array('post'),
	'shortcode_auto_title'  	  => 'Other posts of the serie',
	'shortcode_auto_title_tag' 	  => 'h2',
	'shortcode_auto_listtype'     => 'ol',
	'shortcode_auto_orderby'      => EGS_DEFAULT_POSTS_ORDER_BY,
	'shortcode_auto_order'		  => EGS_DEFAULT_POSTS_ORDER,
	'shortcode_auto_show_date'    => 1,
	'shortcode_auto_expand'   	  => 0,
	'shortcode_auto_default_opts' => 0,
	'date_format'                 => '',
	'series_page'				  => FALSE,  // TODO: to be checked
	'series_url'				  => 1,  // TODO: to be checked
	'custom_post_types'			  => array(),
	'load_css'					  => 0,
	'uninstall_del_series' 		  => 0,
	'uninstall_del_options'       => 0
);

Class EG_Series_Core {

	/**
	 * create_taxonomy
	 *
	 * Create taxonomy
	 *
	 * @param	string	$textdomain			textdomain of the plugin
	 * @param	array	$custom_post_types	list of custom posts types
	 * @return	none
	 */
	static function create_taxonomy($textdomain, $custom_post_types) {

		if ( ! taxonomy_exists(EGS_TAXONOMY)) {

			$labels = array(
				'name' 						 => EGS_TAXONOMY_LABEL,
				'singular_name' 			 => __( 'EG-Series', 		$textdomain),
				'search_items' 				 => __( 'Search series',	$textdomain),
				'popular_items'			 	 => null,
				'all_items' 				 => __( 'All series', 		$textdomain),
				'edit_item' 				 => __( 'Edit a serie', 	$textdomain),
				'update_item' 				 => __( 'Update a serie', 	$textdomain),
				'add_new_item' 				 => __( 'Add a new serie', 	$textdomain),
				'new_item_name' 			 => __( 'New serie Name', 	$textdomain),
				'separate_items_with_commas' => null,
				'add_or_remove_items' 		 => null,
				'choose_from_most_used' 	 => __( 'Choose from most used', $textdomain)
			);

			$structure = get_option( 'permalink_structure' );
			$args = array(  'hierarchical'	=> false,
							'labels' 		=> $labels,
							'query_var' 	=> EGS_TAXONOMY,
							'rewrite' 		=> (empty( $structure )?FALSE:array( 'slug' => EGS_TAXONOMY )));

			register_taxonomy( EGS_TAXONOMY, 'post', $args );
			if (isset($custom_post_types) && sizeof($custom_post_types)>0) {
				foreach ($custom_post_types as $custom_post_type) {
					register_taxonomy_for_object_type(EGS_TAXONOMY, $custom_post_type);
				}
			}

			/* Tentative to avoid 404 error after changing rewrite rules
			- Get rewrite rules
			- if rewrite rules don't contain "serie=" then flush
			*/
			$rewrite_rules = get_option('rewrite_rules');
			if ($rewrite_rules && strpos(implode(',',$rewrite_rules), EGS_TAXONOMY.'=') === FALSE) {
				flush_rewrite_rules();
			}

		} // End of is_taxonomy

	} // End of eg_series_create_taxonomy

	/**
	 * series_list
	 *
	 * List series, and their posts (if requested)
	 *
	 * @param	array	$options			plugin's options
	 * @param	array	$args				shortcode parameters
	 * @return	string						list of the series
	 */
	static function series_list($options, $args) {
		global $EG_SERIES_SHORTCODE_SERIES_DEFAULTS;

		extract(wp_parse_args(
				$args,
				array_merge($EG_SERIES_SHORTCODE_SERIES_DEFAULTS, array( 'auto_submit' => EGS_DEFAULT_AUTOSUBMIT, 'width' => 0)))
			);

		$string = '';

		// Get the list of series
		$series_list = get_terms(EGS_TAXONOMY, array('hide_empty' => false, 'hierarchical' => false));
		if ($series_list) {
			$number_of_serie = 0;

			foreach ($series_list as $serie) {

				// if the serie is empty, and count=0, display nothing
				if ($hide_empty && $serie->count == 0)
					continue;

				// Prepare fields
				$posts_number = ($numposts?' ('.$serie->count.')':'');
				$description  = wp_html_excerpt($serie->description, 254);

				if ($serie->count == 0) $serie_link = FALSE;
				else $serie_link  = self::get_serie_link($options, $serie, $args);

				if ($width>0 && strlen($serie->name)>$width) {
					$serie_name = substr($serie->name, 0, $width).'...';
				}
				else $serie_name = $serie->name;

				// If list of posts are requested, get the posts list
				$list_of_posts = '';
				if ($listposts) {
					$list_of_posts = self::posts_list( $options, array(
						'name'	    	=> $serie->name,
						'listtype'  	=> $listtype,
						'orderby'  		=> $post_orderby,
						'order'	    	=> $post_order,
						'show_date' 	=> $show_date,
						'auto_submit'	=> $auto_submit,
						'include_select' => 0
						)
					);
				} // End of listposts

				// Build the list
				switch ($listtype) {
					case 'ul':
					case 'ol':
						$string .= '<li class="eg-series-series-item">'.
								($serie_link? '<a href="'.$serie_link.'" '.($description==''?'':'title="'.$description.'"').'>' : '').
								htmlspecialchars($serie_name).
								($serie_link? '</a>' : '').
								$posts_number.
								$list_of_posts.
								'</li>';
					break;

					case 'select':
						if ($auto_submit && $serie_link) $value = $serie_link;
						else $value = $serie->term_id;
						if (! $listposts) {
							$string .= '<option class="eg-series-series-item" value="'.$value.'">'.htmlspecialchars($serie_name).'</option>';
						}
						else {
							$string .= '<optgroup class="eg-series-series-item" label="'.htmlspecialchars($serie_name).'">'.
										'<option class="eg-series-posts-item" value="'.$value.'">'.__('The serie',EGS_TEXTDOMAIN).'</option>'.
										$list_of_posts.
										'</optgroup>';
						}
					break;
				} // End of switch

				if ($number>0 && ++$number_of_serie >= $number)
					break;

			} // End foreach $series_list

			if ($string != '') {
				switch ($listtype) {
					case 'ul':
					case 'ol':
						if ($more) {
							$msg = '';
							if( $number>0 && $number<sizeof($series_list)) 
								$msg = sprintf(__('Only %s of %s are displayed. ', EGS_TEXTDOMAIN),$number, sizeof($series_list));
							$msg .= sprintf(__('Click <a href="%s">here</a> to see all series', EGS_TEXTDOMAIN), get_permalink($more));
							$string .= '<li class="eg-series-series-item">'.$msg.'</li>';
						}
						$string = '<'.$listtype.' class="eg-series-series">'.$string.'</'.$listtype.'>';
					break;

					case 'select':
						if ($more && $number>0 && $number<sizeof($series_list)) {
							if (! $listposts) {
							$string .= '<option class="eg-series-series-item" value="'.($auto_submit?get_permalink($more):$more).'" >'.
								__('Display all series', EGS_TEXTDOMAIN).
								'</option>';
							}
							else {
								$string .= '<optgroup class="eg-series-series-item" label="'.__('All series',EGS_TEXTDOMAIN).'">'.
									'<option class="eg-series-posts-item" value="'.($auto_submit?get_permalink($more):$more).'">'.
									__('Display all series',EGS_TEXTDOMAIN).
									'</option>'.
									'</optgroup>';
							}
						}
						$onchange_string = ($auto_submit ? 'onChange="if (this.value!=\'\') { window.location=this.value}" ' : '');
						$string = '<select class="eg-series-series" '.$onchange_string.'>'.$string.'</select>';
					break;
				} // End of switch
			} // End of string not empty
		} // End of $series_list
		return ($string);

	} // End of eg_series_series_list

	/**
	 * eg_serie_add_title
	 *
	 * Add title to a specified string
	 *
	 * @param 	string		the string to modify
	 * @param 	string		$title
	 * @param 	string		$titletag
	 * @return 	string		string with added title
	 */
	static function add_title($string, $title, $titletag) {
		if ($title != '') {
			$string = ($titletag==''?'':'<'.$titletag.'>').
						htmlspecialchars($title).
						($titletag==''?'':'</'.$titletag.'>').
						$string;
		}
		return ($string);
	} // End of eg_serie_add_title

	/**
	 * get_serie_link
	 *
	 * Add title to a specified string
	 *
	 * @param 	array		plugin options list
	 * @param 	object		the serie for which we need the link
	 * @param 	array		array($orderby, $order)
	 * @return 	string		link of the serie
	 */
	static function get_serie_link($options, $serie, $args) {
		global $wp_version;

		$link = FALSE;
		if ($options['series_url'] == 2) {
			$link = get_term_link( $serie, EGS_TAXONOMY );
		}
		else {


			if (version_compare ($wp_version, '3.2', '<')) {
				$query_param = array(EGS_TAXONOMY  => $serie->slug);
			}
			else {
				$query_param = array('tax_query' => array(
					array(
						'taxonomy' 	=> EGS_TAXONOMY,
						'field' 	=> 'slug',
						'terms' 	=> $serie->slug)
					)
				);
			}
			//$orderby = isset($args['post_orderby']) ? $args['post_orderby'] : EGS_DEFAULT_POSTS_ORDER_BY;
			//$order   = isset($args['post_order'])   ? $args['post_order']   : EGS_DEFAULT_POSTS_ORDER;
			
			$list = get_posts( array_merge($query_param, array(
					'orderby' 			=> 'date', // $orderby,
					'order'				=> 'asc', // $order,
					'post_type'			=> array_merge( array('post', 'page'), $options['custom_post_types']),
					'posts_per_page'	=> -1)
					)
				);

			if ($list) {
				$first_post = reset($list);
				$link = get_permalink($first_post->ID);
			}

		} // End of series_url = 1
		return ($link);
	} // serie->count > 0

	/**
	 * get_serie
	 *
	 * Get serie object, according a name of the serie, or the id of one of its posts
	 *
	 * @param 	string		$name	name of the requested serie
	 * @param 	int			$id		id of a posts belonging to serie
	 * @return	object		the serie
	 */
	static function get_serie($name='', $id=0) {
		global $post;

		$serie = FALSE;
		if ($name != '') {
			$serie = get_term_by('name', $name, EGS_TAXONOMY);
		} // End of $name

		if (! $serie) {
			if ($id==0 && isset($post)) $id=$post->ID;
			$serie = get_the_terms($id, EGS_TAXONOMY );
			if ($serie !== FALSE && is_array($serie) && sizeof($serie)>0)
				$serie = reset($serie);
		} // End of $serie_id==0
		return ($serie);
	}

	/**
	 * get_excerpt
	 *
	 * Extract and return excerpt from a post
	 *
	 * @package EG-Series
	 * @param object	$post				$post to extract excerpt
	 * @return string						excerpt of the specified post
	 */
	private function get_excerpt($post) {

		// TODO: manage private posts if required
		if ( post_password_required($post) )
			$string = get_the_password_form();
		else {
			if (! empty($post->post_excerpt)) {
				$string = htmlspecialchars(strip_tags($post->post_excerpt));
			}
			else {
				if ( preg_match('/<!--more(.*?)?-->/', $post->post_content, $matches) ) {
					$string = htmlspecialchars(strip_tags(current(explode($matches[0], $post->post_content, 2))));
				}
				else {
					$string = wp_html_excerpt($post->post_content, 150);
				}
			}
		}
		return ($string);
	} // End of eg_series_get_excerpt


	/**
	 * posts_list
	 *
	 * Implement shortcode to display list of posts
	 *
	 * @param 	none
	 * @return 	none
	 */
	static function posts_list($options, $args) {
		global $EG_SERIES_SHORTCODE_POSTS_DEFAULTS;

		// Manage parameters
		extract(wp_parse_args(
			$args,
			array_merge($EG_SERIES_SHORTCODE_POSTS_DEFAULTS,
				array( 'auto_submit' => EGS_DEFAULT_AUTOSUBMIT, 'width' => 0, 'include_select' => 1)))
		);

		$string = '';

		// Getting serie
		$serie = self::get_serie(isset($name)?$name:'', isset($id)?$id:0);

		// Get posts from the selected serie
		if ($serie) {
			if (! isset($options['custom_post_types'])) 
				$options['custom_post_types'] = array();
			else if (! is_array($options['custom_post_types'])) 
				$options['custom_post_types'] = array($options['custom_post_types']);

			$posts = get_posts(array(
					EGS_TAXONOMY  => $serie->slug,
					'orderby'			=> $orderby,
					'order'				=> $order,
					'post_type'			=> array_merge( array('post', 'page'), $options['custom_post_types']),
					'posts_per_page'	=> -1)
			);

			if ($posts) {
				$date_format = ($options['date_format']!=''?$options['date_format']:get_option('date_format'));
				if ($auto_submit && $listtype=='select')
					$onchange_string = 'onChange="if (this.value!=\'\') { window.location=this.value}" ';
				else
					$onchange_string = '';

				if ($listtype != 'select' || $include_select) {
					$string = '<'.$listtype.' class="eg-series-posts" '.$onchange_string.'>';
				}

				foreach ($posts as $serie_post) {
					// Shorten the title if required
					if ($width>0 && strlen($serie_post->post_title)>$width) {
						$post_title = substr($serie_post->post_title, 0, $width).'...';
					}
					else $post_title = $serie_post->post_title;

					// Manage date
					if ($show_date) $date_string = ' ('.date_i18n($date_format, strtotime($serie_post->post_date)).')';
					else $date_string = '';

					// Manage current post
					global $post;
					if ($serie_post->ID == $post->ID) {
						$this_post = __('(This post)', EGS_TEXTDOMAIN);
						$class     = 'current';
					}
					else {
						$this_post = '';
						$class     = '';
					}
					switch ($listtype) {
						case 'select':
							$string .= '<option class="eg-series-posts-item" value="'.($auto_submit?get_permalink($serie_post->ID):$serie_post->ID).'" '.($class==''?'':'selected').'>'.
									htmlspecialchars($post_title).
									$this_post.
									($show_date?' -'.$date_string:'').
									'</option>';
						break;

						case 'dl':
							$string .= '<dt class="eg-series-post-item '.$class.'">'.
									'<dfn>'.($class==''?'':'<a href="'.$value.'" title="'.$series_post->post_title.'">').$label.($class==''?'':'</a>').'</dfn> '.
									($this_post!=''?'<span class="eg-series-post-this">'.$this_post.'</span>':'').
									($show_date||$expand?' - <span class="eg-series-post-date date">'.$date_string.'</span>':'').
									'</dt>'.
									($expand?'<dd class="eg-series-post-excerpt">'.self::get_excerpt($series_post).'</dd>':'');
						break;

						case 'ul':
						case 'ol':
							$string .= '<li class="eg-series-posts-item '.$class.'">'.
									'<span class="eg-series-post-title">'.
									($class!=''?'':'<a href="'.get_permalink($serie_post->ID).'" title="'.htmlspecialchars($serie_post->post_title).'">').
									htmlspecialchars($post_title).($class!=''?'':'</a>').
									'</span> '.
									($this_post!=''?'<span class="eg-series-post-this">'.$this_post.'</span>':'').
									($show_date?' <span class="eg-series-post-date date">'.$date_string.'</span>':'').
									($expand?'<span class="eg-series-post-excerpt">'.self::get_excerpt($serie_post).'</span>':'').
									'</li>';
						break;
					} // End of switch
				} // End of foreach
				if ($listtype != 'select' || $include_select) {
					$string .= '</'.$listtype.'>';
				}
			} // End of $posts
		} // End of $serie != FALSE
		return ($string);
	} // End of posts_list

} // End of class EG_Series_Core
?>