<?php

if (! class_exists('EG_Series')) {

	/**
	 * Class EG_Series
	 *
	 * Implement a shortcode to display the posts series
	 *
	 */
	Class EG_Series extends EG_Plugin_122 {

		/**
		 * init
		 *
		 * Initialize function: add metabox to the plugin
		 *
		 * @param 	none
		 * @return 	none
		 */
		function init() {
			parent::init();

			EG_Series_Core::create_taxonomy($this->textdomain, $this->options['custom_post_types']);

			add_shortcode($this->options['shortcode_list_posts'],  array(&$this,'posts_shortcode') );
			add_shortcode($this->options['shortcode_list_series'], array(&$this,'series_shortcode') );

			if ( $this->options['shortcode_auto']>0  ) {
				add_filter('get_the_excerpt', array(&$this, 'shortcode_auto_excerpt'));
				add_filter('the_content',     array(&$this, 'shortcode_auto_content'));

			} // End of auto-shortcode activated

		} // End of init

		/**
		 * posts_shortcode
		 *
		 * Implement shortcode to display list of posts
		 *
		 * @param 	none
		 * @return 	none
		 */
		function posts_shortcode($args) {
			global $EG_SERIES_SHORTCODE_POSTS_DEFAULTS;

			$attrs = shortcode_atts( $EG_SERIES_SHORTCODE_POSTS_DEFAULTS, $args );
			$output = EG_Series_Core::posts_list($this->options, $attrs);
			if ($output != '') {
				$output = ($attrs['titletag']!='' ? ($attrs['title']!='' ? '<'.$attrs['titletag'].'>'.htmlspecialchars(strip_tags($attrs['title'])).'</'.$attrs['titletag'].'>': ''):'').$output;
			}
			return ($output);
		} // End of posts_shortcode

		/**
		 * series_shortcode
		 *
		 * Implement shortcode to display series
		 *
		 * @param 	none
		 * @return 	none
		 */
		function series_shortcode($args) {
			global $EG_SERIES_SHORTCODE_SERIES_DEFAULTS;

			$attrs = shortcode_atts( $EG_SERIES_SHORTCODE_SERIES_DEFAULTS, $args );
			$output = EG_Series_Core::series_list($this->options, $attrs);
			if ($output != '') {
				$output = ($attrs['titletag']!='' ? ($attrs['title']!='' ? '<'.$attrs['titletag'].'>'.htmlspecialchars(strip_tags($attrs['title'])).'</'.$attrs['titletag'].'>': ''):'').$output;
			}
			return ($output);
		} // End of series_shortcode

		/**
		 * shortcode_auto_visible
		 *
		 * Define is auto shortcode must be displayed of not.
		 *
		 * @return  int		1 if a shortcode is visble, 0 if not
		 */
		function shortcode_auto_visible() {

			if (! is_array($this->options['shortcode_auto_where']))
				$list = array($this->options['shortcode_auto_where']);
			else
				$list = $this->options['shortcode_auto_where'];

			if (sizeof($list)==4)
				$is_visible = TRUE;
			else {
				if (is_front_page() || is_home()) $current_page = 'home';
				elseif (is_page()) $current_page = 'page';
				elseif (is_single()) $current_page = 'post';
				elseif (is_feed()) $current_page = 'feed';
				elseif (is_archive() || is_category() || is_tag() || is_date() || is_day() || is_month() || is_year()) $current_page = 'index';
				else $current_page='unknown';

				$is_visible = in_array($current_page, $list);
			}
			return ($is_visible);
		} // End of shortcode_auto_visible

		/**
		 * shortcode_auto_check_manual_shortcode
		 *
		 * Detect manual shortcode
		 *
		 * @return  int		1 if a shortcode is detected, 0 if not
		 */
		function shortcode_auto_check_manual_shortcode() {
			global $post;

			$value = FALSE;
			if ($this->options['shortcode_auto_exclusive']>0) {
				if (isset($post)) {
					if (! isset($this->shortcode_exists[$post->ID])) {
						$this->shortcode_exists[$post->ID] = (strpos($post->post_excerpt.' '.$post->post_content, '['.$this->options['shortcode_list_posts']) !== FALSE);
					}
					$value = $this->shortcode_exists[$post->ID];
				}
			} // End of shortcode_auto_exclusive
			return ($value);
		} // End of shortcode_auto_check_manual_shortcode

		/**
		 * get_auto_shortcode_options
		 *
		 * Get auto shortcode options, and translate them to be used in manual shortcode
		 *
		 * @param 	none
		 * @return 	array	options
		 */
		function get_auto_shortcode_options() {
			return (array(
					'title' 		=> $this->options['shortcode_auto_title'],
					'titletag' 		=> $this->options['shortcode_auto_title_tag'],
					'listtype'		=> $this->options['shortcode_auto_listtype'],
					'orderby'		=> $this->options['shortcode_auto_orderby'],
					'order'			=> $this->options['shortcode_auto_order'],
					'show_date'		=> $this->options['shortcode_auto_show_date'],
					'expand'		=> $this->options['shortcode_auto_expand']
				)
			);
		} // End of get_auto_shortcode_options
		
		/**
		 * shortcode_auto_content
		 *
		 * Implement a shortcode to get the list of posts for a specified serie
		 *
		 * @param 	strong	$content	post_content
		 * @return 	string			modified post content
		 */
		function shortcode_auto_content($content = '') {
			global $post;

			if ($this->options['shortcode_auto'] > 0 && $this->shortcode_auto_visible() ) {
				$shortcode_output = $this->posts_shortcode( $this->get_auto_shortcode_options() );

				switch ($this->options['shortcode_auto']) {
					case 2: // At the end of post
						$content .= $shortcode_output;
					break;

					case 3: // Before the excerpt
						if (! $post->post_excerpt)
							$content = $shortcode_output . $content;
					break;

					case 4:
						if ($post->post_excerpt) {
							// Case of manual excerpt
							$content = $shortcode_output . $content;
						}
						else {
							// Case of teaser
							if(strpos($content, 'span id="more-')) {
								$parts = preg_split('/(<span id="more-[0-9]*"><\/span>)/', $content, -1,  PREG_SPLIT_DELIM_CAPTURE);
								$content = $parts[0].$parts[1].$shortcode_output.$parts[2];
							} // End of detect tag "more"
						} // End of teaser case
					break;
				} // End of switch
			} // End of shortcode_auto > 0
			return ($content);
		} // End of shortcode_auto_content

		/**
		 * shortcode_auto_excerpt
		 *
		 * Implement a shortcode to get the list of posts for a specified serie
		 *
		 * @param 	strong	$output	post_excerpt
		 * @return 	string			modified excerpt
		 */
		function shortcode_auto_excerpt($output = '') {

			if ($output && $this->options['shortcode_auto'] == 3 && 
				$this->shortcode_auto_visible() ) {
				$shortcode_output = $this->post_shortcode( get_auto_shortcode_options() );
				$output = $shortcode_output.$output;
			} // End of shortcode_auto == 3
			return ($output);
		} // End of shortcode_auto_excerpt
		
		
	} // End of Class

} // End of if class_exists

/* ---------------------------------------------------------------------------------------------------------
     --- Plugin instance creation
     ------------------------------------------------------------------------------------------------------- */

$eg_series = new EG_Series(EGS_PLUGIN_NAME, EGS_VERSION, EGS_CORE_FILE,
							EGS_TEXTDOMAIN, EGS_OPTIONS_ENTRY, $EG_SERIES_DEFAULT_OPTIONS);
$eg_series->set_stylesheets('css/eg-series.css', FALSE);
$eg_series->set_wp_versions('3.0', '3.3-beta2', TRUE);
if (EGS_DEBUG_MODE) $eg_series->set_debug_mode(TRUE, 'debug.log');
$eg_series->load();

?>