<?php

require_once( dirname( dirname( dirname(__FILE__) ) ).'/eg-series-bootstrap.php');

if (! class_exists('EG_Series_Core')) {
	require_once( dirname( __FILE__)  . '/eg-series-core.inc.php');
}

//Check for rights
if ( !is_user_logged_in() || !current_user_can('edit_posts') )
	wp_die(__('Access not authorized.', EGS_TEXTDOMAIN));

// Get plugin options
$eg_series_options = get_option(EGS_OPTIONS_ENTRY);

// Get list of existing series
$series_array = get_terms(EGS_TAXONOMY, array('hide_empty' => false, 'hierarchical' => false));
$series_list['no_serie'] = __('Display the series to which the current post belongs', EGS_TEXTDOMAIN);
foreach ($series_array as $serie) {
	$series_list[$serie->name] = $serie->name;
} // End of foreach

/* Define default values for post shortcode */
$post_shortcode_default = $EG_SERIES_SHORTCODE_POSTS_DEFAULTS;
$post_shortcode_default['name'] = 'no_serie';

if (! $eg_series_options['shortcode_auto_default_opts']) {
	$post_shortcode_values = $EG_SERIES_SHORTCODE_POSTS_DEFAULTS;
}
else {
	$post_shortcode_values = wp_parse_args(array (
		'title'	    => $eg_series_options['shortcode_auto_title'],
		'titletag'  => $eg_series_options['shortcode_auto_title_tag'],
		'listtype'  => $eg_series_options['shortcode_auto_listtype'],
		'orderby'   => $eg_series_options['shortcode_auto_orderby'],
		'order'	    => $eg_series_options['shortcode_auto_order'],
		'show_date' => $eg_series_options['shortcode_auto_show_date']),
		$EG_SERIES_SHORTCODE_POSTS_DEFAULTS
	);
}
//if (isset($_GET['post_id']))
//	$post_shortcode_values['name'] = reset(wp_get_object_terms($_GET['post_id'], EGS_TAXONOMY, array( 'fields' => 'names')));

/* Define default value for series shortcode */
$serie_shortcode_default = $EG_SERIES_SHORTCODE_SERIES_DEFAULTS;

$select_fields = array(
	'listtype' 	=> array(
		'select' 		=> __('Select',          EGS_TEXTDOMAIN ),
		'ul'     		=> __('Simple list',     EGS_TEXTDOMAIN ),
		'ol'    		=> __('Ordered list',    EGS_TEXTDOMAIN ),
		'dl'    		=> __('Definition list', EGS_TEXTDOMAIN )
	),
	'order' 		=> array(
		'ASC'  			=> __('Ascending', EGS_TEXTDOMAIN ),
		'DESC' 			=> __('Descending', EGS_TEXTDOMAIN )
	),
	'orderby' 		=> array(
		'title'   	 	=> __('Title', EGS_TEXTDOMAIN ),
		'date'   	    => __('Date', EGS_TEXTDOMAIN ),
		'menu_order' 	=> __('User order', EGS_TEXTDOMAIN )
	),
	'post_order' 		=> array(
		'ASC'  			=> __('Ascending', EGS_TEXTDOMAIN ),
		'DESC' 			=> __('Descending', EGS_TEXTDOMAIN )
	),
	'post_orderby' 		=> array(
		'title'   	 	=> __('Title', EGS_TEXTDOMAIN ),
		'date'   	    => __('Date', EGS_TEXTDOMAIN ),
		'menu_order' 	=> __('User order', EGS_TEXTDOMAIN )
	),
	'url' 				=> array(
		'first_post' 	=> __('Link to the first post of the serie', EGS_TEXTDOMAIN ),
		'serie_page' 	=> __('Link to a dedicated page', EGS_TEXTDOMAIN )
	),
	'name'				=> $series_list
);

function get_select($html_id, $key, $current_values, $default_values) {
	global $select_fields;

	$string = '<select id="'.$html_id.'" name="'.$html_id.'">';
	foreach ($select_fields[$key] as $id => $value) {
		if ($current_values[$key] == $id) $selected = 'selected'; else $selected = '';
		$string .= '<option value="'.$id.'" '.$selected.'>'.$value.'</option>';
	}
	$string .= '</select><input type="hidden" name="'.$html_id.'_def" id="'.$html_id.'_def" value="'.$default_values[$key].'" />';
	return $string;
}

@header('Content-Type: ' . get_option('html_type') . '; charset=' . get_option('blog_charset'));
?>
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>EG-Series</title>
	<meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php echo get_option('blog_charset'); ?>" />
	<script language="javascript" type="text/javascript" src="<?php echo site_url(); ?>/wp-includes/js/jquery/jquery.js"></script>
	<script language="javascript" type="text/javascript" src="<?php echo site_url(); ?>/wp-includes/js/tinymce/tiny_mce_popup.js"></script>
	<script language="javascript" type="text/javascript" src="<?php echo get_option('siteurl') ?>/wp-includes/js/tinymce/utils/mctabs.js"></script>
	<script language="javascript" type="text/javascript">
		function init() {
			tinyMCEPopup.resizeToInnerSize();
		}

		jQuery(document).ready( function() {
			jQuery("#serie_listposts").click(function () {
				jQuery("#listposts_only").toggle();
			});
		});

		function getCheckedValue(radioObj) {
			string = "";
			if(!radioObj)
				return "";
			var radioLength = radioObj.length;
			if(radioLength == undefined)
				if(radioObj.checked)
					return radioObj.value;
				else
					return "";
			for(var i = 0; i < radioLength; i++) {
				if(radioObj[i].checked) {
					if (string=="") string = "\"" + radioObj[i].value;
					else string = string + ',' + radioObj[i].value;
				}
			}
			if (string!="") string = string + "\"";
			return string;
		}

		function insertEGSeriesShortCode() {
			var posts_panel  = document.getElementById('posts_panel');
			var series_panel = document.getElementById('series_panel');

			if (posts_panel.className.indexOf('current') != -1) {

				var shortcode_value      	= document.getElementById('post_shortcode_tag').value;
				var post_series_list     	= document.getElementById('post_series_list').value;
				var post_series_list_def 	= document.getElementById('post_series_list_def').value;
				var post_list_title      	= document.getElementById('post_list_title').value;
				var post_list_title_def  	= document.getElementById('post_list_title_def').value;
				var post_list_titletag   	= document.getElementById('post_list_titletag').value;
				var post_list_titletag_def	= document.getElementById('post_list_titletag_def').value;
				var post_typelist   		= document.getElementById('post_typelist').value;
				var post_typelist_def		= document.getElementById('post_typelist_def').value;
				var post_orderby   			= document.getElementById('post_orderby').value;
				var post_orderby_def		= document.getElementById('post_orderby_def').value;
				var post_order  			= document.getElementById('post_order').value;
				var post_order_def			= document.getElementById('post_order_def').value;
				var post_expand				= document.getElementById('post_expand');
				var post_expand_def			= parseInt(document.getElementById('post_expand_def').value);
				var post_showdate			= document.getElementById('post_showdate');
				var post_showdate_def		= parseInt(document.getElementById('post_showdate_def').value);

				var shortcode = '[' + shortcode_value;
				if (post_series_list_def != '' && post_series_list != post_series_list_def)
					shortcode = shortcode + ' name="' + post_series_list + '"';

				if (post_list_title != post_list_title_def)
					shortcode = shortcode + ' title="' + post_list_title + '"';

				if (post_list_titletag != post_list_titletag_def)
					shortcode = shortcode + ' titletag="' + post_list_titletag + '"';

				if (post_typelist != post_typelist_def)
					shortcode = shortcode + ' listtype=' + post_typelist;

				if (post_orderby != post_orderby_def)
					shortcode = shortcode + ' orderby=' + post_orderby;

				if (post_order != post_order_def)
					shortcode = shortcode + ' order=' + post_order;

				if (post_expand.checked) post_expand_value=1;
				else post_expand_value=0;
				if (post_expand_value != post_expand_def)
					shortcode = shortcode + ' expand=' + post_expand_value;

				if (post_showdate.checked) post_showdate_value=1;
				else post_showdate_value=0;
				if (post_showdate_value != post_showdate_def)
					shortcode = shortcode + ' show_date=' + post_showdate_value;
			}

			if (series_panel.className.indexOf('current') != -1) {

				var shortcode_value      	= document.getElementById('serie_shortcode_tag').value;
				var serie_list_title      	= document.getElementById('serie_list_title').value;
				var serie_list_title_def  	= document.getElementById('serie_list_title_def').value;
				var serie_list_titletag     = document.getElementById('serie_list_titletag').value;
				var serie_list_titletag_def = document.getElementById('serie_list_titletag_def').value;
				var serie_typelist   		= document.getElementById('serie_typelist').value;
				var serie_typelist_def		= document.getElementById('serie_typelist_def').value;
				var serie_listposts			= document.getElementById('serie_listposts');
				var serie_listposts_def		= parseInt(document.getElementById('serie_listposts_def').value);
				var serie_numposts			= document.getElementById('serie_numposts');
				var serie_numposts_def		= parseInt(document.getElementById('serie_numposts_def').value);
				var serie_number			= parseInt(document.getElementById('serie_number').value);
				var serie_number_def		= parseInt(document.getElementById('serie_number_def').value);
				var serie_more				= parseInt(document.getElementById('serie_more').value);
				var serie_more_def			= parseInt(document.getElementById('serie_more_def').value);
				var serie_orderby   		= document.getElementById('serie_orderby').value;
				var serie_orderby_def		= document.getElementById('serie_orderby_def').value;
				var serie_order  			= document.getElementById('serie_order').value;
				var serie_order_def			= document.getElementById('serie_order_def').value;
				var serie_showdate			= document.getElementById('serie_showdate');
				var serie_showdate_def		= parseInt(document.getElementById('serie_showdate_def').value);

				var shortcode = '[' + shortcode_value;

				if (serie_list_title != serie_list_title_def)
					shortcode = shortcode + ' title="' + serie_list_title + '"';

				if (serie_list_titletag != serie_list_titletag_def)
					shortcode = shortcode + ' titletag="' + serie_list_titletag + '"';

				if (serie_typelist != serie_typelist_def)
					shortcode = shortcode + ' listtype=' + serie_typelist;

				if (serie_numposts.checked) serie_numposts_value=1;
				else serie_numposts_value=0;
				if (serie_numposts_value != serie_numposts_def)
					shortcode = shortcode + ' numposts=' + serie_numposts_value;

				if (! isNaN(serie_number) && serie_number != serie_number_def)
					shortcode = shortcode + ' number=' + serie_number;

				if (! isNaN(serie_more) && serie_more != serie_more_def)
					shortcode = shortcode + ' more=' + serie_more;

				if (serie_listposts.checked) serie_listposts_value=1;
				else serie_listposts_value=0;
				if (serie_listposts_value != serie_listposts_def)
					shortcode = shortcode + ' listposts=' + serie_listposts_value;

				if (serie_orderby != serie_orderby_def)
					shortcode = shortcode + ' orderby=' + serie_orderby;

				if (serie_order != serie_order_def)
					shortcode = shortcode + ' order=' + serie_order;

				if (serie_showdate.checked) serie_showdate_value=1;
				else serie_showdate_value=0;
				if (serie_showdate_value != serie_showdate_def)
					shortcode = shortcode + ' show_date=' + serie_showdate_value;
			}

			shortcode = shortcode + ']';
			if(window.tinyMCE) {
				window.tinyMCE.execInstanceCommand('content', 'mceInsertContent', false, shortcode);
				// tinyMCEPopup.editor.execCommand('mceRepaint');
				tinyMCEPopup.close();
			}

			tinyMCEPopup.close();
			return;
		}
	</script>
</head>
<body onload="tinyMCEPopup.executeOnLoad('init();');document.body.style.display='';" style="display: none">
	<div class="mceActionPanel">
		<form action="#" method="get" accept-charset="utf-8">
			<div class="tabs">
				<ul>
					<li id="posts_tab" class="current"><span><a href="javascript:mcTabs.displayTab('posts_tab','posts_panel');" onmousedown="return false;"><?php _e("Posts shortcode", EGS_TEXTDOMAIN ); ?></a></span></li>
					<li id="series_tab"><span><a href="javascript:mcTabs.displayTab('series_tab','series_panel');" onmousedown="return false;"><?php _e("Series shortcode", EGS_TEXTDOMAIN); ?></a></span></li>
				</ul>
			</div>

			<div class="panel_wrapper" >
				<div id="posts_panel" class="panel current">
					<input type="hidden" name="post_shortcode_tag" id="post_shortcode_tag" value="<?php echo $eg_series_options['shortcode_list_posts']; ?>" />
					<p>
						<label for="post_series_list"><?php _e('Choose a serie: ',EGS_TEXTDOMAIN); ?></label> 
						<?php echo get_select('post_series_list', 'name', $post_shortcode_values, $post_shortcode_default); ?>
					</p>
					<p>
						<label for="post_list_title"><?php _e('Title of the list: ',EGS_TEXTDOMAIN); ?></label> 
							<input type="text" name="post_list_title" id="post_list_title" value="<?php echo $post_shortcode_values['title']; ?>" />
							<input type="hidden" name="post_list_title_def" id="post_list_title_def" value="<?php echo $post_shortcode_default['title']; ?>" />
					</p>
					<p>
						<label for="post_list_titletag"><?php _e('HTML tag for title: ',EGS_TEXTDOMAIN); ?></label> 
							<input type="text" name="post_list_titletag" id="post_list_titletag" value="<?php echo $post_shortcode_values['titletag']; ?>" />
							<input type="hidden" name="post_list_titletag_def" id="post_list_titletag_def" value="<?php echo $post_shortcode_default['titletag']; ?>" />
					</p>
					<p>
						<label for="post_typelist"><?php _e('Type of list: ',EGS_TEXTDOMAIN); ?></label> 
						<?php echo get_select('post_typelist', 'listtype', $post_shortcode_values, $post_shortcode_default); ?>
					</p>
					<p>
						<label for="post_orderby"><?php _e('Order posts by: ',EGS_TEXTDOMAIN); ?></label><br />
						<?php echo get_select('post_orderby', 'orderby', $post_shortcode_values, $post_shortcode_default); ?>
						<?php echo get_select('post_order', 'order', $post_shortcode_values, $post_shortcode_default); ?>
					</p>
					<p>
						<label for="post_expand"><?php _e('Show posts details',EGS_TEXTDOMAIN); ?>: </label>
						<input type="checkbox" name="post_expand" id="post_expand" <?php echo ($post_shortcode_values['expand']?'checked':'')?> /> <?php _e('Show excerpt of each post?',EGS_TEXTDOMAIN); ?>
						<input type="hidden" name="post_expand_def" id="post_expand_def" value="<?php echo $post_shortcode_default['expand']; ?>" />
					</p>
					<p>
						<input type="checkbox" name="post_showdate" id="post_showdate" <?php echo ($post_shortcode_values['show_date']?'checked':'')?> /> 
						<label for="post_showdate"><?php _e('Show date',EGS_TEXTDOMAIN); ?>: </label>
						<input type="hidden" name="post_showdate_def" id="post_showdate_def" value="<?php echo $post_shortcode_default['show_date']; ?>" />
					</p>
				</div>
				<div id="series_panel" class="panel">
					<input type="hidden" name="serie_shortcode_tag" id="serie_shortcode_tag" value="<?php echo $eg_series_options['shortcode_list_series']; ?>" />
					<p>
						<label for="serie_list_title"><?php _e('Title of the list: ',EGS_TEXTDOMAIN); ?></label>
						<input type="text" name="serie_list_title" id="serie_list_title" />
						<input type="hidden" name="serie_list_title_def" id="serie_list_title_def" value="<?php echo $serie_shortcode_default['title']; ?>" />
					</p>
					<p>
						<label for="serie_list_titletag"><?php _e('HTML tag for title: ',EGS_TEXTDOMAIN); ?></label>
							<input type="text" name="serie_list_titletag" id="serie_list_titletag" value="<?php echo $serie_shortcode_default['titletag']; ?>" size="5" />
							<input type="hidden" name="serie_list_titletag_def" id="serie_list_titletag_def" value="<?php echo $serie_shortcode_default['titletag']; ?>" />
					</p>
					<p>
						<label for="serie_typelist"><?php _e('Type of list: ',EGS_TEXTDOMAIN); ?></label>
						<?php echo get_select('serie_typelist', 'listtype', $serie_shortcode_default, $serie_shortcode_default); ?>
					</p>
					<p>
						<input type="checkbox" name="serie_numposts" id="serie_numposts" <?php echo ($serie_shortcode_default['numposts']?'checked':'')?> /> 
						<label for="serie_numposts"><?php _e('Display number of posts for each serie',EGS_TEXTDOMAIN); ?></label>						<input type="hidden" name="serie_numposts_def" id="serie_numposts_def" value="<?php echo $serie_shortcode_default['numposts']; ?>" />
					</p>
					<p>
						<label for="serie_number"><?php _e('Maximum number of series to display: ',EGS_TEXTDOMAIN); ?></label>
						<input type="text" name="serie_number" id="serie_number" value="<?php echo $serie_shortcode_default['number']; ?>" size="5" />
						<input type="hidden" name="serie_number_def" id="serie_number_def" value="<?php echo $serie_shortcode_default['number']; ?>" />
					</p>
					<p>
						<label for="serie_more"><?php _e('id of post/page to see the whole list of the series: ',EGS_TEXTDOMAIN); ?></label>
						<input type="text" name="serie_more" id="serie_more" value="<?php echo $serie_shortcode_default['more']; ?>" size="5" />
						<input type="hidden" name="serie_more_def" id="serie_more_def" value="<?php echo $serie_shortcode_default['more']; ?>" />
					</p>
					<p>
						<input type="checkbox" id="serie_listposts" <?php echo ($serie_shortcode_default['listposts']?'checked':'')?> /> 
						<label for="serie_listposts"><?php _e('Show posts',EGS_TEXTDOMAIN); ?></label>
						<input type="hidden" name="serie_listposts_def" id="serie_listposts_def" value="<?php echo $serie_shortcode_default['listposts']; ?>" />
					</p>
					<div id="listposts_only" style="display: none">
						<p>
							<label for="serie_orderby"><?php _e('Order posts by: ',EGS_TEXTDOMAIN); ?></label><br />
							<?php echo get_select('serie_orderby', 'post_orderby', $serie_shortcode_default, $serie_shortcode_default); ?>
							<?php echo get_select('serie_order', 'post_order', $serie_shortcode_default, $serie_shortcode_default); ?>
						</p>
						<p>
							<input type="checkbox" name="serie_showdate" id="serie_showdate" <?php echo ($serie_shortcode_default['show_date']?'checked':'')?> /> 
							<label for="serie_showdate"><?php _e('Show date',EGS_TEXTDOMAIN); ?></label>
							<input type="hidden" name="serie_showdate_def" id="serie_showdate_def" value="<?php echo $serie_shortcode_default['show_date']; ?>" />
						</p>
					</div>
				</div>
				<br style="clear: both;" />
			</div>
			<div class="mceActionPanel">
				<div style="float: left">
					<input type="submit" id="insert" name="insert" value="<?php _e("Insert", EGS_TEXTDOMAIN); ?>" onclick="insertEGSeriesShortCode();" />
				</div>
				<div style="float: right">
					<input type="button" id="cancel" name="cancel" value="<?php _e("Cancel", EGS_TEXTDOMAIN); ?>" onclick="tinyMCEPopup.close();" />
				</div>
				<br style="clear: both;" />
			</div>
		</form>
	</div>
</body>
</html>
